==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexcommentwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXCOMMENTWIDGET_H
#define KBIBTEXCOMMENTWIDGET_H

#include <qwidget.h>
#include <qdialog.h>

class BibTeXComment;
class QMultiLineEdit;

class KBibTeXCommentWidget : public QWidget
{
    Q_OBJECT
public:
    KBibTeXCommentWidget( BibTeXComment *comment, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXCommentWidget();

    static QDialog::DialogCode execute( BibTeXComment *comment, const QString& caption, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

private:
    BibTeXComment* m_comment;
    QMultiLineEdit *m_multiLineEdit;

    void setupGUI();
    bool setCommentData();
    void getCommentData();
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexcommentwidget.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXCOMMENTWIDGET_H
#define KBIBTEXCOMMENTWIDGET_H

#include <qwidget.h>
#include <qdialog.h>

class BibTeXComment;
class QMultiLineEdit;
class QCheckBox;

class KBibTeXCommentWidget : public QWidget
{
    Q_OBJECT
public:
    KBibTeXCommentWidget( BibTeX::BibTeXComment *comment, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

    ~KBibTeXCommentWidget();

    static QDialog::DialogCode execute( BibTeX::BibTeXComment *comment, bool isReadWrite, QWidget *parent = 0, const char *name = 0 );

private:
    BibTeX::BibTeXComment* m_comment;
    QCheckBox *m_usePercent;
    QMultiLineEdit *m_multiLineEdit;

    void setupGUI();
    void setCommentData();
    void getCommentData();
};

#endif
